@@ -1,4 +1,4 @@
-from typing import List, Dict, Tuple, Union
+from typing import List, Dict, Tuple
 from .client import FinClient
 from .data.login_data import LoginData
 from .data.market.ohlc_data import OHLCData
@@ -9,14 +9,13 @@ from .data.chart.financial_graph_param_data import FinancialGraphParamData
 from .data.chart.line_graph_param_data import LineGraphParamData
 from .data.chart.ohlc_value_data import OHLCValueData
 from .data.chart.graph_value_data import GraphValueData
+from .data.chart.bar_graph_param_data import BarGraphParamData
 from .data.trade.order_data import OrderData
 from .data.market.market_param_data import MarketParamData
 from .data.market.query_param_data import QueryParamData
 from .data.market.sub_ohlc_param_data import SubOHLCParamData
 from .data.market.history_ohlc_param_data import HistoryOHLCParamData
 from .data.market.fin_persist_read_param_data import FinPersistReadParamData
-from .data.market.history_tick_param_data import HistoryTickParamData
-from .data.market.basetick_data import BaseTickData
 from .data.trade.trade_param_data import TradeParamData
 from .data.trade.read_history_order_param_data import ReadHistoryOrderParamData
 from .data.trade.read_history_tradeorder_param_data import ReadHistoryTradeOrderParamData
@@ -24,7 +23,7 @@ from .data.trade.get_account_param_data import GetAccountParamData
 from .data.trade.get_orders_param_data import GetOrdersParamData
 from .data.trade.get_tradeorders_param_data import GetTradeOrdersParamData
 from .data.trade.get_positions_param_data import GetPositionsParamData
-from .data.chart.bar_graph_param_data import BarGraphParamData
+from .data.trade.read_exc_product_param_data import ReadExcProductParamData
 
 
 def conncet(host: str = None, port: int = None, ):
@@ -327,6 +326,14 @@ def get_history_ohlc(market_name: str, exchang_id: str, instrument_id: str, rang
     )
 
 
+def get_ohlc_column_types():
+    return FinClient.instance().market_handle().get_ohlc_column_types()
+
+
+def get_tick_column_types():
+    return FinClient.instance().market_handle().get_tick_column_types()
+
+
 def fin_save_ohlc_list(instrument_id: str, range: str, df, **kwargs):
     """批量按天保存OHLC数据
 
@@ -343,8 +350,8 @@ def fin_save_ohlc_list(instrument_id: str, range: str, df, **kwargs):
         'HighestBidPrice':float, 'HighestAskPrice':float, 'HighestBidVolume':int, 'HighestAskVolume':int,
         'LowestBidPrice':float, 'LowestAskPrice':float, 'LowestBidVolume':int, 'LowestAskVolume':int,
         'CloseBidPrice':float, 'CloseAskPrice':float, 'CloseBidVolume':int, 'CloseAskVolume':int].
-        compress (str, optional): 压缩方式 Defaults to 'xz'.
-        level 压缩等级
+        compress (str, optional): 压缩方式 Defaults to 'zip'.
+        level 压缩等级 Defaults to -1
         pack 序列化方式 msgpack pickle Defaults to 'msgpack'.
         vacuum 是否直接整理数据文件 Defaults to True.
     Returns:
@@ -368,14 +375,14 @@ def fin_read_ohlc_list(instrument_id: str, range: str, start_date: int, end_date
     return FinClient.instance().market_handle().fin_read_ohlc_list(FinPersistReadParamData(instrument_id=instrument_id, range=range, start_date=start_date, end_date=end_date, base_path=base_path), is_return_list=is_return_list)
 
 
-def fin_save_basetick_list(instrument_id, df, **kwargs):
+def fin_save_tick_list(instrument_id, df, **kwargs):
     """批量按天保存行情数据
 
     Args:
         instrument_id (str, optional) 合约编码 Defaults  to ''.
         df (DataFrame, optional): 数据集
         包含列
-        ['ExchangeID':str, 'InstrumentID':str, 'ActionDay':str, 'ActionTime':str, 'UpdateMillisec':int,
+        ['ExchangeID':str, 'InstrumentID':str, 'ActionDay':str, 'ActionTime':str, 'ActionMSec':int,
         'LastPrice':float, 'LastVolume':int, 'BidPrice':float, 'BidVolume':int, 'AskPrice':float, 'AskVolume':int,
         'TotalTurnover':float, 'TotalVolume':int, 'OpenInterest':float, 'PreClosePrice':float,
         'PreSettlementPrice':float, 'PreOpenInterest':float]
@@ -387,10 +394,10 @@ def fin_save_basetick_list(instrument_id, df, **kwargs):
     Returns:
         _type_: [bool,str]
     """
-    return FinClient.instance().market_handle().fin_save_basetick_list(instrument_id=instrument_id, df=df, kwargs=kwargs)
+    return FinClient.instance().market_handle().fin_save_tick_list(instrument_id, df, **kwargs)
 
 
-def fin_read_basetick_list(instrument_id: str, start_date: int = 0, end_date: int = 99999999, base_path: str = '', is_return_list: bool = False):
+def fin_read_tick_list(instrument_id: str, start_date: int = 0, end_date: int = 99999999, base_path: str = '', is_return_list: bool = False):
     '''
     获取basetick数据
     :param instrument_id:合约编码
@@ -400,7 +407,7 @@ def fin_read_basetick_list(instrument_id: str, start_date: int = 0, end_date: in
     :param is_return_list 是否返回list格式
     :return: result,msg
     '''
-    return FinClient.instance().market_handle().fin_read_basetick_list(
+    return FinClient.instance().market_handle().fin_read_tick_list(
         FinPersistReadParamData(table_name=instrument_id, range='BTick', start_date=start_date,
                                 end_date=end_date, base_path=base_path), is_return_list=is_return_list)
 
@@ -457,6 +464,10 @@ def read_history_tradeorders(start_date: str, end_date: str):
     )
 
 
+def read_exc_products(exchange_id: str, product_id: str):
+    return FinClient.instance().trade_handle().read_exc_products(ReadExcProductParamData(exchange_id=exchange_id, product_id=product_id))
+
+
 def get_orders(trade_name: str):
     return FinClient.instance().trade_handle().get_orders(
         GetOrdersParamData(
